@@ -21,7 +21,6 @@ import org.scilab.forge.scirenderer.implementation.g2d.buffers.G2DBuffersManager
 import org.scilab.forge.scirenderer.implementation.g2d.motor.Motor3D;
 import org.scilab.forge.scirenderer.implementation.g2d.renderer.G2DRendererManager;
 import org.scilab.forge.scirenderer.implementation.g2d.texture.G2DTextureManager;
-import org.scilab.forge.scirenderer.texture.TextureManager;
 import org.scilab.forge.scirenderer.picking.PickingManager;
 import org.scilab.forge.scirenderer.picking.PickingTask;
 
@@ -145,4 +144,10 @@ public final class G2DCanvas implements Canvas {
     public Motor3D getMotor3D() {
         return motor;
     }
+
+    @Override
+    public void destroy() {
+        // TODO Auto-generated method stub
+        
+    }
 }
