@@ -224,12 +224,22 @@ public final class JoGLCanvas implements Canvas, GLEventListener {
      * @return an image
      */
     public BufferedImage getImage() {
-        GLContext context = autoDrawable.getContext();
-        context.makeCurrent();
-        BufferedImage image = Screenshot.readToBufferedImage(autoDrawable.getWidth(), autoDrawable.getHeight());
-        context.release();
+        while (!canvasAnimator.isDrawFinished()) {
+            try {
+                Thread.sleep(10);
+            } catch (InterruptedException e) {
+                break;
+            }
+        }
 
-        return image;
+        synchronized (canvasAnimator) {
+            GLContext context = autoDrawable.getContext();
+            context.makeCurrent();
+            BufferedImage image = Screenshot.readToBufferedImage(autoDrawable.getWidth(), autoDrawable.getHeight());
+            context.release();
+
+            return image;
+        }
     }
 
     /**
@@ -341,8 +351,12 @@ public final class JoGLCanvas implements Canvas, GLEventListener {
         }
 
 
+        public boolean isDrawFinished() {
+            return semaphore.availablePermits() == 0;
+        }
+
         /** Ask the animator to perform a draw later. */
-        public void redraw() {
+        public synchronized void redraw() {
             semaphore.release();
         }
 
