@@ -11,11 +11,18 @@
 
 package org.scilab.forge.scirenderer.implementation.jogl;
 
+import javax.media.opengl.GL;
+import javax.media.opengl.glu.GLU;
+
 /**
  * @author Pierre Lando
  */
 public class JoGLParameters {
 
+    private static final boolean USE_DISPLAY_LIST = false;
+    private static final boolean USE_POINT_SPRITE = true;
+    private static Boolean USE_VBO;
+
     /**
      * Default constructor.
      * It's package : only JoGLCanvas need this kind of object.
@@ -28,7 +35,7 @@ public class JoGLParameters {
      * @return true if use display list.
      */
     public boolean useDisplayList() {
-        return false;
+        return USE_DISPLAY_LIST;
     }
 
     /**
@@ -36,7 +43,15 @@ public class JoGLParameters {
      * @return true if use VBO.
      */
     public boolean useVBO() {
-        return true;
+        if (USE_VBO == null) {
+            GL gl = GLU.getCurrentGL();
+            USE_VBO = gl.isFunctionAvailable("glBindBufferARB")
+                && gl.isFunctionAvailable("glGenBuffersARB")
+                && gl.isFunctionAvailable("glBufferDataARB")
+                && gl.isFunctionAvailable("glDeleteBuffersARB");
+        }
+
+        return USE_VBO;
     }
 
     /**
@@ -44,6 +59,6 @@ public class JoGLParameters {
      * @return true if use point sprite.
      */
     public boolean usePointSprite() {
-        return true;
+        return USE_POINT_SPRITE;
     }
 }
