@@ -106,6 +106,11 @@ public final class DefaultRulerModel implements RulerModel {
      */
     private Graduations userGraduation;
 
+    /**
+     * Line width
+     */
+    private double lineWidth = DEFAULT_LINE_WIDTH;
+    
     /**
      * Default constructor.
      */
@@ -364,4 +369,18 @@ public final class DefaultRulerModel implements RulerModel {
     public void setColor(Color color) {
         this.color = color;
     }
+
+    @Override
+    public double getLineWidth() {
+        return lineWidth;
+    }
+    
+    /**
+     * Ruler line width setter
+     * @param lineWidth the new line width
+     */
+    public void setLineWidth(double lineWidth) {
+        this.lineWidth = lineWidth;
+    }
+
 }
